# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppArgs', 'App']

@pulumi.input_type
class AppArgs:
    def __init__(__self__, *,
                 container_app_environment_id: pulumi.Input[str],
                 resource_group_name: pulumi.Input[str],
                 revision_mode: pulumi.Input[str],
                 template: pulumi.Input['AppTemplateArgs'],
                 dapr: Optional[pulumi.Input['AppDaprArgs']] = None,
                 identity: Optional[pulumi.Input['AppIdentityArgs']] = None,
                 ingress: Optional[pulumi.Input['AppIngressArgs']] = None,
                 max_inactive_revisions: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 registries: Optional[pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 workload_profile_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a App resource.
        :param pulumi.Input[str] container_app_environment_id: The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_mode: The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        :param pulumi.Input['AppTemplateArgs'] template: A `template` block as detailed below.
        :param pulumi.Input['AppDaprArgs'] dapr: A `dapr` block as detailed below.
        :param pulumi.Input['AppIdentityArgs'] identity: An `identity` block as detailed below.
        :param pulumi.Input['AppIngressArgs'] ingress: An `ingress` block as detailed below.
        :param pulumi.Input[int] max_inactive_revisions: The maximum of inactive revisions allowed for this Container App.
        :param pulumi.Input[str] name: The name for this Container App. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]] registries: A `registry` block as detailed below.
        :param pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]] secrets: One or more `secret` block as detailed below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the Container App.
        :param pulumi.Input[str] workload_profile_name: The name of the Workload Profile in the Container App Environment to place this Container App.
               
               > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        pulumi.set(__self__, "container_app_environment_id", container_app_environment_id)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "revision_mode", revision_mode)
        pulumi.set(__self__, "template", template)
        if dapr is not None:
            pulumi.set(__self__, "dapr", dapr)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if ingress is not None:
            pulumi.set(__self__, "ingress", ingress)
        if max_inactive_revisions is not None:
            pulumi.set(__self__, "max_inactive_revisions", max_inactive_revisions)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if registries is not None:
            pulumi.set(__self__, "registries", registries)
        if secrets is not None:
            pulumi.set(__self__, "secrets", secrets)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if workload_profile_name is not None:
            pulumi.set(__self__, "workload_profile_name", workload_profile_name)

    @property
    @pulumi.getter(name="containerAppEnvironmentId")
    def container_app_environment_id(self) -> pulumi.Input[str]:
        """
        The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "container_app_environment_id")

    @container_app_environment_id.setter
    def container_app_environment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "container_app_environment_id", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="revisionMode")
    def revision_mode(self) -> pulumi.Input[str]:
        """
        The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        """
        return pulumi.get(self, "revision_mode")

    @revision_mode.setter
    def revision_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "revision_mode", value)

    @property
    @pulumi.getter
    def template(self) -> pulumi.Input['AppTemplateArgs']:
        """
        A `template` block as detailed below.
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: pulumi.Input['AppTemplateArgs']):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter
    def dapr(self) -> Optional[pulumi.Input['AppDaprArgs']]:
        """
        A `dapr` block as detailed below.
        """
        return pulumi.get(self, "dapr")

    @dapr.setter
    def dapr(self, value: Optional[pulumi.Input['AppDaprArgs']]):
        pulumi.set(self, "dapr", value)

    @property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['AppIdentityArgs']]:
        """
        An `identity` block as detailed below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['AppIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @property
    @pulumi.getter
    def ingress(self) -> Optional[pulumi.Input['AppIngressArgs']]:
        """
        An `ingress` block as detailed below.
        """
        return pulumi.get(self, "ingress")

    @ingress.setter
    def ingress(self, value: Optional[pulumi.Input['AppIngressArgs']]):
        pulumi.set(self, "ingress", value)

    @property
    @pulumi.getter(name="maxInactiveRevisions")
    def max_inactive_revisions(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum of inactive revisions allowed for this Container App.
        """
        return pulumi.get(self, "max_inactive_revisions")

    @max_inactive_revisions.setter
    def max_inactive_revisions(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_inactive_revisions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this Container App. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def registries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]]]:
        """
        A `registry` block as detailed below.
        """
        return pulumi.get(self, "registries")

    @registries.setter
    def registries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]]]):
        pulumi.set(self, "registries", value)

    @property
    @pulumi.getter
    def secrets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]]]:
        """
        One or more `secret` block as detailed below.
        """
        return pulumi.get(self, "secrets")

    @secrets.setter
    def secrets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]]]):
        pulumi.set(self, "secrets", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the Container App.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="workloadProfileName")
    def workload_profile_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Workload Profile in the Container App Environment to place this Container App.

        > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        return pulumi.get(self, "workload_profile_name")

    @workload_profile_name.setter
    def workload_profile_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "workload_profile_name", value)


@pulumi.input_type
class _AppState:
    def __init__(__self__, *,
                 container_app_environment_id: Optional[pulumi.Input[str]] = None,
                 custom_domain_verification_id: Optional[pulumi.Input[str]] = None,
                 dapr: Optional[pulumi.Input['AppDaprArgs']] = None,
                 identity: Optional[pulumi.Input['AppIdentityArgs']] = None,
                 ingress: Optional[pulumi.Input['AppIngressArgs']] = None,
                 latest_revision_fqdn: Optional[pulumi.Input[str]] = None,
                 latest_revision_name: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 max_inactive_revisions: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 outbound_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 registries: Optional[pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 revision_mode: Optional[pulumi.Input[str]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 template: Optional[pulumi.Input['AppTemplateArgs']] = None,
                 workload_profile_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering App resources.
        :param pulumi.Input[str] container_app_environment_id: The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] custom_domain_verification_id: The ID of the Custom Domain Verification for this Container App.
        :param pulumi.Input['AppDaprArgs'] dapr: A `dapr` block as detailed below.
        :param pulumi.Input['AppIdentityArgs'] identity: An `identity` block as detailed below.
        :param pulumi.Input['AppIngressArgs'] ingress: An `ingress` block as detailed below.
        :param pulumi.Input[str] latest_revision_fqdn: The FQDN of the Latest Revision of the Container App.
        :param pulumi.Input[str] latest_revision_name: The name of the latest Container Revision.
        :param pulumi.Input[str] location: The location this Container App is deployed in. This is the same as the Environment in which it is deployed.
        :param pulumi.Input[int] max_inactive_revisions: The maximum of inactive revisions allowed for this Container App.
        :param pulumi.Input[str] name: The name for this Container App. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] outbound_ip_addresses: A list of the Public IP Addresses which the Container App uses for outbound network access.
        :param pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]] registries: A `registry` block as detailed below.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_mode: The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        :param pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]] secrets: One or more `secret` block as detailed below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the Container App.
        :param pulumi.Input['AppTemplateArgs'] template: A `template` block as detailed below.
        :param pulumi.Input[str] workload_profile_name: The name of the Workload Profile in the Container App Environment to place this Container App.
               
               > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        if container_app_environment_id is not None:
            pulumi.set(__self__, "container_app_environment_id", container_app_environment_id)
        if custom_domain_verification_id is not None:
            pulumi.set(__self__, "custom_domain_verification_id", custom_domain_verification_id)
        if dapr is not None:
            pulumi.set(__self__, "dapr", dapr)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if ingress is not None:
            pulumi.set(__self__, "ingress", ingress)
        if latest_revision_fqdn is not None:
            pulumi.set(__self__, "latest_revision_fqdn", latest_revision_fqdn)
        if latest_revision_name is not None:
            pulumi.set(__self__, "latest_revision_name", latest_revision_name)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if max_inactive_revisions is not None:
            pulumi.set(__self__, "max_inactive_revisions", max_inactive_revisions)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if outbound_ip_addresses is not None:
            pulumi.set(__self__, "outbound_ip_addresses", outbound_ip_addresses)
        if registries is not None:
            pulumi.set(__self__, "registries", registries)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if revision_mode is not None:
            pulumi.set(__self__, "revision_mode", revision_mode)
        if secrets is not None:
            pulumi.set(__self__, "secrets", secrets)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if workload_profile_name is not None:
            pulumi.set(__self__, "workload_profile_name", workload_profile_name)

    @property
    @pulumi.getter(name="containerAppEnvironmentId")
    def container_app_environment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "container_app_environment_id")

    @container_app_environment_id.setter
    def container_app_environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_app_environment_id", value)

    @property
    @pulumi.getter(name="customDomainVerificationId")
    def custom_domain_verification_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Custom Domain Verification for this Container App.
        """
        return pulumi.get(self, "custom_domain_verification_id")

    @custom_domain_verification_id.setter
    def custom_domain_verification_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "custom_domain_verification_id", value)

    @property
    @pulumi.getter
    def dapr(self) -> Optional[pulumi.Input['AppDaprArgs']]:
        """
        A `dapr` block as detailed below.
        """
        return pulumi.get(self, "dapr")

    @dapr.setter
    def dapr(self, value: Optional[pulumi.Input['AppDaprArgs']]):
        pulumi.set(self, "dapr", value)

    @property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['AppIdentityArgs']]:
        """
        An `identity` block as detailed below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['AppIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @property
    @pulumi.getter
    def ingress(self) -> Optional[pulumi.Input['AppIngressArgs']]:
        """
        An `ingress` block as detailed below.
        """
        return pulumi.get(self, "ingress")

    @ingress.setter
    def ingress(self, value: Optional[pulumi.Input['AppIngressArgs']]):
        pulumi.set(self, "ingress", value)

    @property
    @pulumi.getter(name="latestRevisionFqdn")
    def latest_revision_fqdn(self) -> Optional[pulumi.Input[str]]:
        """
        The FQDN of the Latest Revision of the Container App.
        """
        return pulumi.get(self, "latest_revision_fqdn")

    @latest_revision_fqdn.setter
    def latest_revision_fqdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "latest_revision_fqdn", value)

    @property
    @pulumi.getter(name="latestRevisionName")
    def latest_revision_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the latest Container Revision.
        """
        return pulumi.get(self, "latest_revision_name")

    @latest_revision_name.setter
    def latest_revision_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "latest_revision_name", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location this Container App is deployed in. This is the same as the Environment in which it is deployed.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="maxInactiveRevisions")
    def max_inactive_revisions(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum of inactive revisions allowed for this Container App.
        """
        return pulumi.get(self, "max_inactive_revisions")

    @max_inactive_revisions.setter
    def max_inactive_revisions(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_inactive_revisions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this Container App. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="outboundIpAddresses")
    def outbound_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of the Public IP Addresses which the Container App uses for outbound network access.
        """
        return pulumi.get(self, "outbound_ip_addresses")

    @outbound_ip_addresses.setter
    def outbound_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "outbound_ip_addresses", value)

    @property
    @pulumi.getter
    def registries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]]]:
        """
        A `registry` block as detailed below.
        """
        return pulumi.get(self, "registries")

    @registries.setter
    def registries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppRegistryArgs']]]]):
        pulumi.set(self, "registries", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="revisionMode")
    def revision_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        """
        return pulumi.get(self, "revision_mode")

    @revision_mode.setter
    def revision_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "revision_mode", value)

    @property
    @pulumi.getter
    def secrets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]]]:
        """
        One or more `secret` block as detailed below.
        """
        return pulumi.get(self, "secrets")

    @secrets.setter
    def secrets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppSecretArgs']]]]):
        pulumi.set(self, "secrets", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the Container App.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input['AppTemplateArgs']]:
        """
        A `template` block as detailed below.
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input['AppTemplateArgs']]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter(name="workloadProfileName")
    def workload_profile_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Workload Profile in the Container App Environment to place this Container App.

        > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        return pulumi.get(self, "workload_profile_name")

    @workload_profile_name.setter
    def workload_profile_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "workload_profile_name", value)


class App(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_app_environment_id: Optional[pulumi.Input[str]] = None,
                 dapr: Optional[pulumi.Input[Union['AppDaprArgs', 'AppDaprArgsDict']]] = None,
                 identity: Optional[pulumi.Input[Union['AppIdentityArgs', 'AppIdentityArgsDict']]] = None,
                 ingress: Optional[pulumi.Input[Union['AppIngressArgs', 'AppIngressArgsDict']]] = None,
                 max_inactive_revisions: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 registries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppRegistryArgs', 'AppRegistryArgsDict']]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 revision_mode: Optional[pulumi.Input[str]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppSecretArgs', 'AppSecretArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 template: Optional[pulumi.Input[Union['AppTemplateArgs', 'AppTemplateArgsDict']]] = None,
                 workload_profile_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Container App.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_analytics_workspace = azure.operationalinsights.AnalyticsWorkspace("example",
            name="acctest-01",
            location=example.location,
            resource_group_name=example.name,
            sku="PerGB2018",
            retention_in_days=30)
        example_environment = azure.containerapp.Environment("example",
            name="Example-Environment",
            location=example.location,
            resource_group_name=example.name,
            log_analytics_workspace_id=example_analytics_workspace.id)
        example_app = azure.containerapp.App("example",
            name="example-app",
            container_app_environment_id=example_environment.id,
            resource_group_name=example.name,
            revision_mode="Single",
            template={
                "containers": [{
                    "name": "examplecontainerapp",
                    "image": "mcr.microsoft.com/k8se/quickstart:latest",
                    "cpu": 0.25,
                    "memory": "0.5Gi",
                }],
            })
        ```

        ## Import

        A Container App can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:containerapp/app:App example "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resGroup1/providers/Microsoft.App/containerApps/myContainerApp"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] container_app_environment_id: The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['AppDaprArgs', 'AppDaprArgsDict']] dapr: A `dapr` block as detailed below.
        :param pulumi.Input[Union['AppIdentityArgs', 'AppIdentityArgsDict']] identity: An `identity` block as detailed below.
        :param pulumi.Input[Union['AppIngressArgs', 'AppIngressArgsDict']] ingress: An `ingress` block as detailed below.
        :param pulumi.Input[int] max_inactive_revisions: The maximum of inactive revisions allowed for this Container App.
        :param pulumi.Input[str] name: The name for this Container App. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppRegistryArgs', 'AppRegistryArgsDict']]]] registries: A `registry` block as detailed below.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_mode: The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppSecretArgs', 'AppSecretArgsDict']]]] secrets: One or more `secret` block as detailed below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the Container App.
        :param pulumi.Input[Union['AppTemplateArgs', 'AppTemplateArgsDict']] template: A `template` block as detailed below.
        :param pulumi.Input[str] workload_profile_name: The name of the Workload Profile in the Container App Environment to place this Container App.
               
               > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Container App.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_analytics_workspace = azure.operationalinsights.AnalyticsWorkspace("example",
            name="acctest-01",
            location=example.location,
            resource_group_name=example.name,
            sku="PerGB2018",
            retention_in_days=30)
        example_environment = azure.containerapp.Environment("example",
            name="Example-Environment",
            location=example.location,
            resource_group_name=example.name,
            log_analytics_workspace_id=example_analytics_workspace.id)
        example_app = azure.containerapp.App("example",
            name="example-app",
            container_app_environment_id=example_environment.id,
            resource_group_name=example.name,
            revision_mode="Single",
            template={
                "containers": [{
                    "name": "examplecontainerapp",
                    "image": "mcr.microsoft.com/k8se/quickstart:latest",
                    "cpu": 0.25,
                    "memory": "0.5Gi",
                }],
            })
        ```

        ## Import

        A Container App can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:containerapp/app:App example "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resGroup1/providers/Microsoft.App/containerApps/myContainerApp"
        ```

        :param str resource_name: The name of the resource.
        :param AppArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_app_environment_id: Optional[pulumi.Input[str]] = None,
                 dapr: Optional[pulumi.Input[Union['AppDaprArgs', 'AppDaprArgsDict']]] = None,
                 identity: Optional[pulumi.Input[Union['AppIdentityArgs', 'AppIdentityArgsDict']]] = None,
                 ingress: Optional[pulumi.Input[Union['AppIngressArgs', 'AppIngressArgsDict']]] = None,
                 max_inactive_revisions: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 registries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppRegistryArgs', 'AppRegistryArgsDict']]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 revision_mode: Optional[pulumi.Input[str]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppSecretArgs', 'AppSecretArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 template: Optional[pulumi.Input[Union['AppTemplateArgs', 'AppTemplateArgsDict']]] = None,
                 workload_profile_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppArgs.__new__(AppArgs)

            if container_app_environment_id is None and not opts.urn:
                raise TypeError("Missing required property 'container_app_environment_id'")
            __props__.__dict__["container_app_environment_id"] = container_app_environment_id
            __props__.__dict__["dapr"] = dapr
            __props__.__dict__["identity"] = identity
            __props__.__dict__["ingress"] = ingress
            __props__.__dict__["max_inactive_revisions"] = max_inactive_revisions
            __props__.__dict__["name"] = name
            __props__.__dict__["registries"] = registries
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if revision_mode is None and not opts.urn:
                raise TypeError("Missing required property 'revision_mode'")
            __props__.__dict__["revision_mode"] = revision_mode
            __props__.__dict__["secrets"] = None if secrets is None else pulumi.Output.secret(secrets)
            __props__.__dict__["tags"] = tags
            if template is None and not opts.urn:
                raise TypeError("Missing required property 'template'")
            __props__.__dict__["template"] = template
            __props__.__dict__["workload_profile_name"] = workload_profile_name
            __props__.__dict__["custom_domain_verification_id"] = None
            __props__.__dict__["latest_revision_fqdn"] = None
            __props__.__dict__["latest_revision_name"] = None
            __props__.__dict__["location"] = None
            __props__.__dict__["outbound_ip_addresses"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["customDomainVerificationId", "secrets"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(App, __self__).__init__(
            'azure:containerapp/app:App',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            container_app_environment_id: Optional[pulumi.Input[str]] = None,
            custom_domain_verification_id: Optional[pulumi.Input[str]] = None,
            dapr: Optional[pulumi.Input[Union['AppDaprArgs', 'AppDaprArgsDict']]] = None,
            identity: Optional[pulumi.Input[Union['AppIdentityArgs', 'AppIdentityArgsDict']]] = None,
            ingress: Optional[pulumi.Input[Union['AppIngressArgs', 'AppIngressArgsDict']]] = None,
            latest_revision_fqdn: Optional[pulumi.Input[str]] = None,
            latest_revision_name: Optional[pulumi.Input[str]] = None,
            location: Optional[pulumi.Input[str]] = None,
            max_inactive_revisions: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            outbound_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            registries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppRegistryArgs', 'AppRegistryArgsDict']]]]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            revision_mode: Optional[pulumi.Input[str]] = None,
            secrets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppSecretArgs', 'AppSecretArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            template: Optional[pulumi.Input[Union['AppTemplateArgs', 'AppTemplateArgsDict']]] = None,
            workload_profile_name: Optional[pulumi.Input[str]] = None) -> 'App':
        """
        Get an existing App resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] container_app_environment_id: The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] custom_domain_verification_id: The ID of the Custom Domain Verification for this Container App.
        :param pulumi.Input[Union['AppDaprArgs', 'AppDaprArgsDict']] dapr: A `dapr` block as detailed below.
        :param pulumi.Input[Union['AppIdentityArgs', 'AppIdentityArgsDict']] identity: An `identity` block as detailed below.
        :param pulumi.Input[Union['AppIngressArgs', 'AppIngressArgsDict']] ingress: An `ingress` block as detailed below.
        :param pulumi.Input[str] latest_revision_fqdn: The FQDN of the Latest Revision of the Container App.
        :param pulumi.Input[str] latest_revision_name: The name of the latest Container Revision.
        :param pulumi.Input[str] location: The location this Container App is deployed in. This is the same as the Environment in which it is deployed.
        :param pulumi.Input[int] max_inactive_revisions: The maximum of inactive revisions allowed for this Container App.
        :param pulumi.Input[str] name: The name for this Container App. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] outbound_ip_addresses: A list of the Public IP Addresses which the Container App uses for outbound network access.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppRegistryArgs', 'AppRegistryArgsDict']]]] registries: A `registry` block as detailed below.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_mode: The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppSecretArgs', 'AppSecretArgsDict']]]] secrets: One or more `secret` block as detailed below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the Container App.
        :param pulumi.Input[Union['AppTemplateArgs', 'AppTemplateArgsDict']] template: A `template` block as detailed below.
        :param pulumi.Input[str] workload_profile_name: The name of the Workload Profile in the Container App Environment to place this Container App.
               
               > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppState.__new__(_AppState)

        __props__.__dict__["container_app_environment_id"] = container_app_environment_id
        __props__.__dict__["custom_domain_verification_id"] = custom_domain_verification_id
        __props__.__dict__["dapr"] = dapr
        __props__.__dict__["identity"] = identity
        __props__.__dict__["ingress"] = ingress
        __props__.__dict__["latest_revision_fqdn"] = latest_revision_fqdn
        __props__.__dict__["latest_revision_name"] = latest_revision_name
        __props__.__dict__["location"] = location
        __props__.__dict__["max_inactive_revisions"] = max_inactive_revisions
        __props__.__dict__["name"] = name
        __props__.__dict__["outbound_ip_addresses"] = outbound_ip_addresses
        __props__.__dict__["registries"] = registries
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["revision_mode"] = revision_mode
        __props__.__dict__["secrets"] = secrets
        __props__.__dict__["tags"] = tags
        __props__.__dict__["template"] = template
        __props__.__dict__["workload_profile_name"] = workload_profile_name
        return App(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="containerAppEnvironmentId")
    def container_app_environment_id(self) -> pulumi.Output[str]:
        """
        The ID of the Container App Environment within which this Container App should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "container_app_environment_id")

    @property
    @pulumi.getter(name="customDomainVerificationId")
    def custom_domain_verification_id(self) -> pulumi.Output[str]:
        """
        The ID of the Custom Domain Verification for this Container App.
        """
        return pulumi.get(self, "custom_domain_verification_id")

    @property
    @pulumi.getter
    def dapr(self) -> pulumi.Output[Optional['outputs.AppDapr']]:
        """
        A `dapr` block as detailed below.
        """
        return pulumi.get(self, "dapr")

    @property
    @pulumi.getter
    def identity(self) -> pulumi.Output[Optional['outputs.AppIdentity']]:
        """
        An `identity` block as detailed below.
        """
        return pulumi.get(self, "identity")

    @property
    @pulumi.getter
    def ingress(self) -> pulumi.Output[Optional['outputs.AppIngress']]:
        """
        An `ingress` block as detailed below.
        """
        return pulumi.get(self, "ingress")

    @property
    @pulumi.getter(name="latestRevisionFqdn")
    def latest_revision_fqdn(self) -> pulumi.Output[str]:
        """
        The FQDN of the Latest Revision of the Container App.
        """
        return pulumi.get(self, "latest_revision_fqdn")

    @property
    @pulumi.getter(name="latestRevisionName")
    def latest_revision_name(self) -> pulumi.Output[str]:
        """
        The name of the latest Container Revision.
        """
        return pulumi.get(self, "latest_revision_name")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The location this Container App is deployed in. This is the same as the Environment in which it is deployed.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="maxInactiveRevisions")
    def max_inactive_revisions(self) -> pulumi.Output[Optional[int]]:
        """
        The maximum of inactive revisions allowed for this Container App.
        """
        return pulumi.get(self, "max_inactive_revisions")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name for this Container App. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="outboundIpAddresses")
    def outbound_ip_addresses(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of the Public IP Addresses which the Container App uses for outbound network access.
        """
        return pulumi.get(self, "outbound_ip_addresses")

    @property
    @pulumi.getter
    def registries(self) -> pulumi.Output[Optional[Sequence['outputs.AppRegistry']]]:
        """
        A `registry` block as detailed below.
        """
        return pulumi.get(self, "registries")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the resource group in which the Container App Environment is to be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="revisionMode")
    def revision_mode(self) -> pulumi.Output[str]:
        """
        The revisions operational mode for the Container App. Possible values include `Single` and `Multiple`. In `Single` mode, a single revision is in operation at any given time. In `Multiple` mode, more than one revision can be active at a time and can be configured with load distribution via the `traffic_weight` block in the `ingress` configuration.
        """
        return pulumi.get(self, "revision_mode")

    @property
    @pulumi.getter
    def secrets(self) -> pulumi.Output[Optional[Sequence['outputs.AppSecret']]]:
        """
        One or more `secret` block as detailed below.
        """
        return pulumi.get(self, "secrets")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the Container App.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output['outputs.AppTemplate']:
        """
        A `template` block as detailed below.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter(name="workloadProfileName")
    def workload_profile_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the Workload Profile in the Container App Environment to place this Container App.

        > **Note:** Omit this value to use the default `Consumption` Workload Profile.
        """
        return pulumi.get(self, "workload_profile_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ActionCustomArgs', 'ActionCustom']

@pulumi.input_type
class ActionCustomArgs:
    def __init__(__self__, *,
                 body: pulumi.Input[str],
                 logic_app_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ActionCustom resource.
        :param pulumi.Input[str] body: Specifies the JSON Blob defining the Body of this Custom Action.
        :param pulumi.Input[str] logic_app_id: Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.
               
               > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        pulumi.set(__self__, "body", body)
        pulumi.set(__self__, "logic_app_id", logic_app_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def body(self) -> pulumi.Input[str]:
        """
        Specifies the JSON Blob defining the Body of this Custom Action.
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: pulumi.Input[str]):
        pulumi.set(self, "body", value)

    @property
    @pulumi.getter(name="logicAppId")
    def logic_app_id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "logic_app_id")

    @logic_app_id.setter
    def logic_app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "logic_app_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.

        > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ActionCustomState:
    def __init__(__self__, *,
                 body: Optional[pulumi.Input[str]] = None,
                 logic_app_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ActionCustom resources.
        :param pulumi.Input[str] body: Specifies the JSON Blob defining the Body of this Custom Action.
        :param pulumi.Input[str] logic_app_id: Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.
               
               > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        if body is not None:
            pulumi.set(__self__, "body", body)
        if logic_app_id is not None:
            pulumi.set(__self__, "logic_app_id", logic_app_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def body(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the JSON Blob defining the Body of this Custom Action.
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "body", value)

    @property
    @pulumi.getter(name="logicAppId")
    def logic_app_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "logic_app_id")

    @logic_app_id.setter
    def logic_app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logic_app_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.

        > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class ActionCustom(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[str]] = None,
                 logic_app_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Custom Action within a Logic App Workflow

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="workflow-resources",
            location="West Europe")
        example_workflow = azure.logicapps.Workflow("example",
            name="workflow1",
            location=example.location,
            resource_group_name=example.name)
        example_action_custom = azure.logicapps.ActionCustom("example",
            name="example-action",
            logic_app_id=example_workflow.id,
            body=\"\"\"{
            "description": "A variable to configure the auto expiration age in days. Configured in negative number. Default is -30 (30 days old).",
            "inputs": {
                "variables": [
                    {
                        "name": "ExpirationAgeInDays",
                        "type": "Integer",
                        "value": -30
                    }
                ]
            },
            "runAfter": {},
            "type": "InitializeVariable"
        }
        \"\"\")
        ```

        ## Import

        Logic App Custom Actions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:logicapps/actionCustom:ActionCustom custom1 /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Logic/workflows/workflow1/actions/custom1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body: Specifies the JSON Blob defining the Body of this Custom Action.
        :param pulumi.Input[str] logic_app_id: Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.
               
               > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ActionCustomArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Custom Action within a Logic App Workflow

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="workflow-resources",
            location="West Europe")
        example_workflow = azure.logicapps.Workflow("example",
            name="workflow1",
            location=example.location,
            resource_group_name=example.name)
        example_action_custom = azure.logicapps.ActionCustom("example",
            name="example-action",
            logic_app_id=example_workflow.id,
            body=\"\"\"{
            "description": "A variable to configure the auto expiration age in days. Configured in negative number. Default is -30 (30 days old).",
            "inputs": {
                "variables": [
                    {
                        "name": "ExpirationAgeInDays",
                        "type": "Integer",
                        "value": -30
                    }
                ]
            },
            "runAfter": {},
            "type": "InitializeVariable"
        }
        \"\"\")
        ```

        ## Import

        Logic App Custom Actions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:logicapps/actionCustom:ActionCustom custom1 /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Logic/workflows/workflow1/actions/custom1
        ```

        :param str resource_name: The name of the resource.
        :param ActionCustomArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ActionCustomArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[str]] = None,
                 logic_app_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ActionCustomArgs.__new__(ActionCustomArgs)

            if body is None and not opts.urn:
                raise TypeError("Missing required property 'body'")
            __props__.__dict__["body"] = body
            if logic_app_id is None and not opts.urn:
                raise TypeError("Missing required property 'logic_app_id'")
            __props__.__dict__["logic_app_id"] = logic_app_id
            __props__.__dict__["name"] = name
        super(ActionCustom, __self__).__init__(
            'azure:logicapps/actionCustom:ActionCustom',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            body: Optional[pulumi.Input[str]] = None,
            logic_app_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'ActionCustom':
        """
        Get an existing ActionCustom resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body: Specifies the JSON Blob defining the Body of this Custom Action.
        :param pulumi.Input[str] logic_app_id: Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.
               
               > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ActionCustomState.__new__(_ActionCustomState)

        __props__.__dict__["body"] = body
        __props__.__dict__["logic_app_id"] = logic_app_id
        __props__.__dict__["name"] = name
        return ActionCustom(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def body(self) -> pulumi.Output[str]:
        """
        Specifies the JSON Blob defining the Body of this Custom Action.
        """
        return pulumi.get(self, "body")

    @property
    @pulumi.getter(name="logicAppId")
    def logic_app_id(self) -> pulumi.Output[str]:
        """
        Specifies the ID of the Logic App Workflow. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "logic_app_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the HTTP Action to be created within the Logic App Workflow. Changing this forces a new resource to be created.

        > **NOTE:** This name must be unique across all Actions within the Logic App Workflow.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'LedgerAzureadBasedServicePrincipalArgs',
    'LedgerAzureadBasedServicePrincipalArgsDict',
    'LedgerCertificateBasedSecurityPrincipalArgs',
    'LedgerCertificateBasedSecurityPrincipalArgsDict',
]

MYPY = False

if not MYPY:
    class LedgerAzureadBasedServicePrincipalArgsDict(TypedDict):
        ledger_role_name: pulumi.Input[str]
        """
        Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        principal_id: pulumi.Input[str]
        """
        Specifies the Principal ID of the AzureAD Service Principal.
        """
        tenant_id: pulumi.Input[str]
        """
        Specifies the Tenant ID for this AzureAD Service Principal.
        """
elif False:
    LedgerAzureadBasedServicePrincipalArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LedgerAzureadBasedServicePrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 principal_id: pulumi.Input[str],
                 tenant_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] principal_id: Specifies the Principal ID of the AzureAD Service Principal.
        :param pulumi.Input[str] tenant_id: Specifies the Tenant ID for this AzureAD Service Principal.
        """
        pulumi.set(__self__, "ledger_role_name", ledger_role_name)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> pulumi.Input[str]:
        """
        Specifies the Principal ID of the AzureAD Service Principal.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        Specifies the Tenant ID for this AzureAD Service Principal.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)


if not MYPY:
    class LedgerCertificateBasedSecurityPrincipalArgsDict(TypedDict):
        ledger_role_name: pulumi.Input[str]
        """
        Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        pem_public_key: pulumi.Input[str]
        """
        The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
elif False:
    LedgerCertificateBasedSecurityPrincipalArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LedgerCertificateBasedSecurityPrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 pem_public_key: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] pem_public_key: The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        pulumi.set(__self__, "ledger_role_name", ledger_role_name)
        pulumi.set(__self__, "pem_public_key", pem_public_key)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="pemPublicKey")
    def pem_public_key(self) -> pulumi.Input[str]:
        """
        The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        return pulumi.get(self, "pem_public_key")

    @pem_public_key.setter
    def pem_public_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "pem_public_key", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FunctionAppActiveSlotArgs', 'FunctionAppActiveSlot']

@pulumi.input_type
class FunctionAppActiveSlotArgs:
    def __init__(__self__, *,
                 slot_id: pulumi.Input[str],
                 overwrite_network_config: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a FunctionAppActiveSlot resource.
        :param pulumi.Input[str] slot_id: The ID of the Slot to swap with `Production`.
        :param pulumi.Input[bool] overwrite_network_config: The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "slot_id", slot_id)
        if overwrite_network_config is not None:
            pulumi.set(__self__, "overwrite_network_config", overwrite_network_config)

    @property
    @pulumi.getter(name="slotId")
    def slot_id(self) -> pulumi.Input[str]:
        """
        The ID of the Slot to swap with `Production`.
        """
        return pulumi.get(self, "slot_id")

    @slot_id.setter
    def slot_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "slot_id", value)

    @property
    @pulumi.getter(name="overwriteNetworkConfig")
    def overwrite_network_config(self) -> Optional[pulumi.Input[bool]]:
        """
        The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "overwrite_network_config")

    @overwrite_network_config.setter
    def overwrite_network_config(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "overwrite_network_config", value)


@pulumi.input_type
class _FunctionAppActiveSlotState:
    def __init__(__self__, *,
                 last_successful_swap: Optional[pulumi.Input[str]] = None,
                 overwrite_network_config: Optional[pulumi.Input[bool]] = None,
                 slot_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FunctionAppActiveSlot resources.
        :param pulumi.Input[str] last_successful_swap: The timestamp of the last successful swap with `Production`
        :param pulumi.Input[bool] overwrite_network_config: The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_id: The ID of the Slot to swap with `Production`.
        """
        if last_successful_swap is not None:
            pulumi.set(__self__, "last_successful_swap", last_successful_swap)
        if overwrite_network_config is not None:
            pulumi.set(__self__, "overwrite_network_config", overwrite_network_config)
        if slot_id is not None:
            pulumi.set(__self__, "slot_id", slot_id)

    @property
    @pulumi.getter(name="lastSuccessfulSwap")
    def last_successful_swap(self) -> Optional[pulumi.Input[str]]:
        """
        The timestamp of the last successful swap with `Production`
        """
        return pulumi.get(self, "last_successful_swap")

    @last_successful_swap.setter
    def last_successful_swap(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_successful_swap", value)

    @property
    @pulumi.getter(name="overwriteNetworkConfig")
    def overwrite_network_config(self) -> Optional[pulumi.Input[bool]]:
        """
        The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "overwrite_network_config")

    @overwrite_network_config.setter
    def overwrite_network_config(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "overwrite_network_config", value)

    @property
    @pulumi.getter(name="slotId")
    def slot_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Slot to swap with `Production`.
        """
        return pulumi.get(self, "slot_id")

    @slot_id.setter
    def slot_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slot_id", value)


class FunctionAppActiveSlot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 overwrite_network_config: Optional[pulumi.Input[bool]] = None,
                 slot_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Function App Active Slot.

        ## Example Usage

        ### Windows Function App

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_account = azure.storage.Account("example",
            name="windowsfunctionappsa",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_service_plan = azure.appservice.ServicePlan("example",
            name="example-app-service-plan",
            resource_group_name=example.name,
            location=example.location,
            os_type="Windows",
            sku_name="Y1")
        example_windows_function_app = azure.appservice.WindowsFunctionApp("example",
            name="example-windows-function-app",
            resource_group_name=example.name,
            location=example.location,
            storage_account_name=example_account.name,
            service_plan_id=example_service_plan.id,
            site_config={})
        example_windows_function_app_slot = azure.appservice.WindowsFunctionAppSlot("example",
            name="example-windows-function-app-slot",
            function_app_id=example_windows_function_app.id,
            storage_account_name=example_account.name,
            site_config={})
        example_function_app_active_slot = azure.appservice.FunctionAppActiveSlot("example", slot_id=example_windows_function_app_slot.id)
        ```

        ### Linux Function App

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_account = azure.storage.Account("example",
            name="linuxfunctionappsa",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_service_plan = azure.appservice.ServicePlan("example",
            name="example-app-service-plan",
            resource_group_name=example.name,
            location=example.location,
            os_type="Linux",
            sku_name="Y1")
        example_linux_function_app = azure.appservice.LinuxFunctionApp("example",
            name="example-linux-function-app",
            resource_group_name=example.name,
            location=example.location,
            service_plan_id=example_service_plan.id,
            storage_account_name=example_account.name,
            site_config={})
        example_linux_function_app_slot = azure.appservice.LinuxFunctionAppSlot("example",
            name="example-linux-function-app-slot",
            function_app_id=example_linux_function_app.name,
            storage_account_name=example_account.name,
            site_config={})
        example_function_app_active_slot = azure.appservice.FunctionAppActiveSlot("example", slot_id=example_linux_function_app_slot.id)
        ```

        ## Import

        a Function App Active Slot can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appservice/functionAppActiveSlot:FunctionAppActiveSlot example "/subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/resGroup1/providers/Microsoft.Web/sites/site1"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] overwrite_network_config: The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_id: The ID of the Slot to swap with `Production`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FunctionAppActiveSlotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Function App Active Slot.

        ## Example Usage

        ### Windows Function App

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_account = azure.storage.Account("example",
            name="windowsfunctionappsa",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_service_plan = azure.appservice.ServicePlan("example",
            name="example-app-service-plan",
            resource_group_name=example.name,
            location=example.location,
            os_type="Windows",
            sku_name="Y1")
        example_windows_function_app = azure.appservice.WindowsFunctionApp("example",
            name="example-windows-function-app",
            resource_group_name=example.name,
            location=example.location,
            storage_account_name=example_account.name,
            service_plan_id=example_service_plan.id,
            site_config={})
        example_windows_function_app_slot = azure.appservice.WindowsFunctionAppSlot("example",
            name="example-windows-function-app-slot",
            function_app_id=example_windows_function_app.id,
            storage_account_name=example_account.name,
            site_config={})
        example_function_app_active_slot = azure.appservice.FunctionAppActiveSlot("example", slot_id=example_windows_function_app_slot.id)
        ```

        ### Linux Function App

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_account = azure.storage.Account("example",
            name="linuxfunctionappsa",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_service_plan = azure.appservice.ServicePlan("example",
            name="example-app-service-plan",
            resource_group_name=example.name,
            location=example.location,
            os_type="Linux",
            sku_name="Y1")
        example_linux_function_app = azure.appservice.LinuxFunctionApp("example",
            name="example-linux-function-app",
            resource_group_name=example.name,
            location=example.location,
            service_plan_id=example_service_plan.id,
            storage_account_name=example_account.name,
            site_config={})
        example_linux_function_app_slot = azure.appservice.LinuxFunctionAppSlot("example",
            name="example-linux-function-app-slot",
            function_app_id=example_linux_function_app.name,
            storage_account_name=example_account.name,
            site_config={})
        example_function_app_active_slot = azure.appservice.FunctionAppActiveSlot("example", slot_id=example_linux_function_app_slot.id)
        ```

        ## Import

        a Function App Active Slot can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appservice/functionAppActiveSlot:FunctionAppActiveSlot example "/subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/resGroup1/providers/Microsoft.Web/sites/site1"
        ```

        :param str resource_name: The name of the resource.
        :param FunctionAppActiveSlotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FunctionAppActiveSlotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 overwrite_network_config: Optional[pulumi.Input[bool]] = None,
                 slot_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FunctionAppActiveSlotArgs.__new__(FunctionAppActiveSlotArgs)

            __props__.__dict__["overwrite_network_config"] = overwrite_network_config
            if slot_id is None and not opts.urn:
                raise TypeError("Missing required property 'slot_id'")
            __props__.__dict__["slot_id"] = slot_id
            __props__.__dict__["last_successful_swap"] = None
        super(FunctionAppActiveSlot, __self__).__init__(
            'azure:appservice/functionAppActiveSlot:FunctionAppActiveSlot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            last_successful_swap: Optional[pulumi.Input[str]] = None,
            overwrite_network_config: Optional[pulumi.Input[bool]] = None,
            slot_id: Optional[pulumi.Input[str]] = None) -> 'FunctionAppActiveSlot':
        """
        Get an existing FunctionAppActiveSlot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] last_successful_swap: The timestamp of the last successful swap with `Production`
        :param pulumi.Input[bool] overwrite_network_config: The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_id: The ID of the Slot to swap with `Production`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FunctionAppActiveSlotState.__new__(_FunctionAppActiveSlotState)

        __props__.__dict__["last_successful_swap"] = last_successful_swap
        __props__.__dict__["overwrite_network_config"] = overwrite_network_config
        __props__.__dict__["slot_id"] = slot_id
        return FunctionAppActiveSlot(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="lastSuccessfulSwap")
    def last_successful_swap(self) -> pulumi.Output[str]:
        """
        The timestamp of the last successful swap with `Production`
        """
        return pulumi.get(self, "last_successful_swap")

    @property
    @pulumi.getter(name="overwriteNetworkConfig")
    def overwrite_network_config(self) -> pulumi.Output[Optional[bool]]:
        """
        The swap action should overwrite the Production slot's network configuration with the configuration from this slot. Defaults to `true`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "overwrite_network_config")

    @property
    @pulumi.getter(name="slotId")
    def slot_id(self) -> pulumi.Output[str]:
        """
        The ID of the Slot to swap with `Production`.
        """
        return pulumi.get(self, "slot_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServicesCommunicationsGatewayArgs', 'ServicesCommunicationsGateway']

@pulumi.input_type
class ServicesCommunicationsGatewayArgs:
    def __init__(__self__, *,
                 codecs: pulumi.Input[str],
                 connectivity: pulumi.Input[str],
                 e911_type: pulumi.Input[str],
                 platforms: pulumi.Input[Sequence[pulumi.Input[str]]],
                 resource_group_name: pulumi.Input[str],
                 service_locations: pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]],
                 api_bridge: Optional[pulumi.Input[str]] = None,
                 auto_generated_domain_name_label_scope: Optional[pulumi.Input[str]] = None,
                 emergency_dial_strings: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 microsoft_teams_voicemail_pilot_number: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 on_prem_mcp_enabled: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ServicesCommunicationsGateway resource.
        :param pulumi.Input[str] codecs: The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        :param pulumi.Input[str] connectivity: How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        :param pulumi.Input[str] e911_type: How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] platforms: The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        :param pulumi.Input[str] resource_group_name: Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]] service_locations: A `service_location` block as defined below.
        :param pulumi.Input[str] api_bridge: Details of API bridge functionality, if required.
        :param pulumi.Input[str] auto_generated_domain_name_label_scope: Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] emergency_dial_strings: A list of dial strings used for emergency calling.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] microsoft_teams_voicemail_pilot_number: This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] on_prem_mcp_enabled: Whether an on-premises Mobile Control Point is in use.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        pulumi.set(__self__, "codecs", codecs)
        pulumi.set(__self__, "connectivity", connectivity)
        pulumi.set(__self__, "e911_type", e911_type)
        pulumi.set(__self__, "platforms", platforms)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "service_locations", service_locations)
        if api_bridge is not None:
            pulumi.set(__self__, "api_bridge", api_bridge)
        if auto_generated_domain_name_label_scope is not None:
            pulumi.set(__self__, "auto_generated_domain_name_label_scope", auto_generated_domain_name_label_scope)
        if emergency_dial_strings is not None:
            pulumi.set(__self__, "emergency_dial_strings", emergency_dial_strings)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if microsoft_teams_voicemail_pilot_number is not None:
            pulumi.set(__self__, "microsoft_teams_voicemail_pilot_number", microsoft_teams_voicemail_pilot_number)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if on_prem_mcp_enabled is not None:
            pulumi.set(__self__, "on_prem_mcp_enabled", on_prem_mcp_enabled)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def codecs(self) -> pulumi.Input[str]:
        """
        The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        """
        return pulumi.get(self, "codecs")

    @codecs.setter
    def codecs(self, value: pulumi.Input[str]):
        pulumi.set(self, "codecs", value)

    @property
    @pulumi.getter
    def connectivity(self) -> pulumi.Input[str]:
        """
        How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        """
        return pulumi.get(self, "connectivity")

    @connectivity.setter
    def connectivity(self, value: pulumi.Input[str]):
        pulumi.set(self, "connectivity", value)

    @property
    @pulumi.getter(name="e911Type")
    def e911_type(self) -> pulumi.Input[str]:
        """
        How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        """
        return pulumi.get(self, "e911_type")

    @e911_type.setter
    def e911_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "e911_type", value)

    @property
    @pulumi.getter
    def platforms(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        """
        return pulumi.get(self, "platforms")

    @platforms.setter
    def platforms(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "platforms", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="serviceLocations")
    def service_locations(self) -> pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]]:
        """
        A `service_location` block as defined below.
        """
        return pulumi.get(self, "service_locations")

    @service_locations.setter
    def service_locations(self, value: pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]]):
        pulumi.set(self, "service_locations", value)

    @property
    @pulumi.getter(name="apiBridge")
    def api_bridge(self) -> Optional[pulumi.Input[str]]:
        """
        Details of API bridge functionality, if required.
        """
        return pulumi.get(self, "api_bridge")

    @api_bridge.setter
    def api_bridge(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_bridge", value)

    @property
    @pulumi.getter(name="autoGeneratedDomainNameLabelScope")
    def auto_generated_domain_name_label_scope(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        """
        return pulumi.get(self, "auto_generated_domain_name_label_scope")

    @auto_generated_domain_name_label_scope.setter
    def auto_generated_domain_name_label_scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_generated_domain_name_label_scope", value)

    @property
    @pulumi.getter(name="emergencyDialStrings")
    def emergency_dial_strings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of dial strings used for emergency calling.
        """
        return pulumi.get(self, "emergency_dial_strings")

    @emergency_dial_strings.setter
    def emergency_dial_strings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "emergency_dial_strings", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="microsoftTeamsVoicemailPilotNumber")
    def microsoft_teams_voicemail_pilot_number(self) -> Optional[pulumi.Input[str]]:
        """
        This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        """
        return pulumi.get(self, "microsoft_teams_voicemail_pilot_number")

    @microsoft_teams_voicemail_pilot_number.setter
    def microsoft_teams_voicemail_pilot_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "microsoft_teams_voicemail_pilot_number", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="onPremMcpEnabled")
    def on_prem_mcp_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether an on-premises Mobile Control Point is in use.
        """
        return pulumi.get(self, "on_prem_mcp_enabled")

    @on_prem_mcp_enabled.setter
    def on_prem_mcp_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "on_prem_mcp_enabled", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ServicesCommunicationsGatewayState:
    def __init__(__self__, *,
                 api_bridge: Optional[pulumi.Input[str]] = None,
                 auto_generated_domain_name_label_scope: Optional[pulumi.Input[str]] = None,
                 codecs: Optional[pulumi.Input[str]] = None,
                 connectivity: Optional[pulumi.Input[str]] = None,
                 e911_type: Optional[pulumi.Input[str]] = None,
                 emergency_dial_strings: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 microsoft_teams_voicemail_pilot_number: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 on_prem_mcp_enabled: Optional[pulumi.Input[bool]] = None,
                 platforms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 service_locations: Optional[pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ServicesCommunicationsGateway resources.
        :param pulumi.Input[str] api_bridge: Details of API bridge functionality, if required.
        :param pulumi.Input[str] auto_generated_domain_name_label_scope: Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        :param pulumi.Input[str] codecs: The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        :param pulumi.Input[str] connectivity: How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        :param pulumi.Input[str] e911_type: How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] emergency_dial_strings: A list of dial strings used for emergency calling.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] microsoft_teams_voicemail_pilot_number: This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] on_prem_mcp_enabled: Whether an on-premises Mobile Control Point is in use.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] platforms: The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        :param pulumi.Input[str] resource_group_name: Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]] service_locations: A `service_location` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        if api_bridge is not None:
            pulumi.set(__self__, "api_bridge", api_bridge)
        if auto_generated_domain_name_label_scope is not None:
            pulumi.set(__self__, "auto_generated_domain_name_label_scope", auto_generated_domain_name_label_scope)
        if codecs is not None:
            pulumi.set(__self__, "codecs", codecs)
        if connectivity is not None:
            pulumi.set(__self__, "connectivity", connectivity)
        if e911_type is not None:
            pulumi.set(__self__, "e911_type", e911_type)
        if emergency_dial_strings is not None:
            pulumi.set(__self__, "emergency_dial_strings", emergency_dial_strings)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if microsoft_teams_voicemail_pilot_number is not None:
            pulumi.set(__self__, "microsoft_teams_voicemail_pilot_number", microsoft_teams_voicemail_pilot_number)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if on_prem_mcp_enabled is not None:
            pulumi.set(__self__, "on_prem_mcp_enabled", on_prem_mcp_enabled)
        if platforms is not None:
            pulumi.set(__self__, "platforms", platforms)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if service_locations is not None:
            pulumi.set(__self__, "service_locations", service_locations)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="apiBridge")
    def api_bridge(self) -> Optional[pulumi.Input[str]]:
        """
        Details of API bridge functionality, if required.
        """
        return pulumi.get(self, "api_bridge")

    @api_bridge.setter
    def api_bridge(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_bridge", value)

    @property
    @pulumi.getter(name="autoGeneratedDomainNameLabelScope")
    def auto_generated_domain_name_label_scope(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        """
        return pulumi.get(self, "auto_generated_domain_name_label_scope")

    @auto_generated_domain_name_label_scope.setter
    def auto_generated_domain_name_label_scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_generated_domain_name_label_scope", value)

    @property
    @pulumi.getter
    def codecs(self) -> Optional[pulumi.Input[str]]:
        """
        The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        """
        return pulumi.get(self, "codecs")

    @codecs.setter
    def codecs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "codecs", value)

    @property
    @pulumi.getter
    def connectivity(self) -> Optional[pulumi.Input[str]]:
        """
        How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        """
        return pulumi.get(self, "connectivity")

    @connectivity.setter
    def connectivity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connectivity", value)

    @property
    @pulumi.getter(name="e911Type")
    def e911_type(self) -> Optional[pulumi.Input[str]]:
        """
        How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        """
        return pulumi.get(self, "e911_type")

    @e911_type.setter
    def e911_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "e911_type", value)

    @property
    @pulumi.getter(name="emergencyDialStrings")
    def emergency_dial_strings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of dial strings used for emergency calling.
        """
        return pulumi.get(self, "emergency_dial_strings")

    @emergency_dial_strings.setter
    def emergency_dial_strings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "emergency_dial_strings", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="microsoftTeamsVoicemailPilotNumber")
    def microsoft_teams_voicemail_pilot_number(self) -> Optional[pulumi.Input[str]]:
        """
        This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        """
        return pulumi.get(self, "microsoft_teams_voicemail_pilot_number")

    @microsoft_teams_voicemail_pilot_number.setter
    def microsoft_teams_voicemail_pilot_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "microsoft_teams_voicemail_pilot_number", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="onPremMcpEnabled")
    def on_prem_mcp_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether an on-premises Mobile Control Point is in use.
        """
        return pulumi.get(self, "on_prem_mcp_enabled")

    @on_prem_mcp_enabled.setter
    def on_prem_mcp_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "on_prem_mcp_enabled", value)

    @property
    @pulumi.getter
    def platforms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        """
        return pulumi.get(self, "platforms")

    @platforms.setter
    def platforms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "platforms", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="serviceLocations")
    def service_locations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]]]:
        """
        A `service_location` block as defined below.
        """
        return pulumi.get(self, "service_locations")

    @service_locations.setter
    def service_locations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServicesCommunicationsGatewayServiceLocationArgs']]]]):
        pulumi.set(self, "service_locations", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class ServicesCommunicationsGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_bridge: Optional[pulumi.Input[str]] = None,
                 auto_generated_domain_name_label_scope: Optional[pulumi.Input[str]] = None,
                 codecs: Optional[pulumi.Input[str]] = None,
                 connectivity: Optional[pulumi.Input[str]] = None,
                 e911_type: Optional[pulumi.Input[str]] = None,
                 emergency_dial_strings: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 microsoft_teams_voicemail_pilot_number: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 on_prem_mcp_enabled: Optional[pulumi.Input[bool]] = None,
                 platforms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 service_locations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServicesCommunicationsGatewayServiceLocationArgs', 'ServicesCommunicationsGatewayServiceLocationArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Manages a Voice Services Communications Gateways.

        !> **NOTE:** You must have signed an Operator Connect agreement with Microsoft to use this resource. For more information, see [`Prerequisites`](https://learn.microsoft.com/en-us/azure/communications-gateway/prepare-to-deploy#prerequisites).

        !> **NOTE:** Access to Azure Communications Gateway is restricted, see [`Get access to Azure Communications Gateway for your Azure subscription`](https://learn.microsoft.com/en-us/azure/communications-gateway/prepare-to-deploy#9-get-access-to-azure-communications-gateway-for-your-azure-subscription) for details.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_services_communications_gateway = azure.voice.ServicesCommunicationsGateway("example",
            name="example-vcg",
            location="West Europe",
            resource_group_name=example.name,
            connectivity="PublicAddress",
            codecs="PCMA",
            e911_type="DirectToEsrp",
            platforms=[
                "OperatorConnect",
                "TeamsPhoneMobile",
            ],
            service_locations=[
                {
                    "location": "eastus",
                    "allowed_media_source_address_prefixes": ["10.1.2.0/24"],
                    "allowed_signaling_source_address_prefixes": ["10.1.1.0/24"],
                    "esrp_addresses": ["198.51.100.3"],
                    "operator_addresses": ["198.51.100.1"],
                },
                {
                    "location": "eastus2",
                    "allowed_media_source_address_prefixes": ["10.2.2.0/24"],
                    "allowed_signaling_source_address_prefixes": ["10.2.1.0/24"],
                    "esrp_addresses": ["198.51.100.4"],
                    "operator_addresses": ["198.51.100.2"],
                },
            ],
            auto_generated_domain_name_label_scope="SubscriptionReuse",
            api_bridge=json.dumps({}),
            emergency_dial_strings=[
                "911",
                "933",
            ],
            on_prem_mcp_enabled=False,
            tags={
                "key": "value",
            },
            microsoft_teams_voicemail_pilot_number="1")
        ```

        ## Import

        Voice Services Communications Gateways can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:voice/servicesCommunicationsGateway:ServicesCommunicationsGateway example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.VoiceServices/communicationsGateways/communicationsGateway1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_bridge: Details of API bridge functionality, if required.
        :param pulumi.Input[str] auto_generated_domain_name_label_scope: Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        :param pulumi.Input[str] codecs: The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        :param pulumi.Input[str] connectivity: How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        :param pulumi.Input[str] e911_type: How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] emergency_dial_strings: A list of dial strings used for emergency calling.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] microsoft_teams_voicemail_pilot_number: This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] on_prem_mcp_enabled: Whether an on-premises Mobile Control Point is in use.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] platforms: The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        :param pulumi.Input[str] resource_group_name: Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServicesCommunicationsGatewayServiceLocationArgs', 'ServicesCommunicationsGatewayServiceLocationArgsDict']]]] service_locations: A `service_location` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServicesCommunicationsGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Voice Services Communications Gateways.

        !> **NOTE:** You must have signed an Operator Connect agreement with Microsoft to use this resource. For more information, see [`Prerequisites`](https://learn.microsoft.com/en-us/azure/communications-gateway/prepare-to-deploy#prerequisites).

        !> **NOTE:** Access to Azure Communications Gateway is restricted, see [`Get access to Azure Communications Gateway for your Azure subscription`](https://learn.microsoft.com/en-us/azure/communications-gateway/prepare-to-deploy#9-get-access-to-azure-communications-gateway-for-your-azure-subscription) for details.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_services_communications_gateway = azure.voice.ServicesCommunicationsGateway("example",
            name="example-vcg",
            location="West Europe",
            resource_group_name=example.name,
            connectivity="PublicAddress",
            codecs="PCMA",
            e911_type="DirectToEsrp",
            platforms=[
                "OperatorConnect",
                "TeamsPhoneMobile",
            ],
            service_locations=[
                {
                    "location": "eastus",
                    "allowed_media_source_address_prefixes": ["10.1.2.0/24"],
                    "allowed_signaling_source_address_prefixes": ["10.1.1.0/24"],
                    "esrp_addresses": ["198.51.100.3"],
                    "operator_addresses": ["198.51.100.1"],
                },
                {
                    "location": "eastus2",
                    "allowed_media_source_address_prefixes": ["10.2.2.0/24"],
                    "allowed_signaling_source_address_prefixes": ["10.2.1.0/24"],
                    "esrp_addresses": ["198.51.100.4"],
                    "operator_addresses": ["198.51.100.2"],
                },
            ],
            auto_generated_domain_name_label_scope="SubscriptionReuse",
            api_bridge=json.dumps({}),
            emergency_dial_strings=[
                "911",
                "933",
            ],
            on_prem_mcp_enabled=False,
            tags={
                "key": "value",
            },
            microsoft_teams_voicemail_pilot_number="1")
        ```

        ## Import

        Voice Services Communications Gateways can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:voice/servicesCommunicationsGateway:ServicesCommunicationsGateway example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.VoiceServices/communicationsGateways/communicationsGateway1
        ```

        :param str resource_name: The name of the resource.
        :param ServicesCommunicationsGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServicesCommunicationsGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_bridge: Optional[pulumi.Input[str]] = None,
                 auto_generated_domain_name_label_scope: Optional[pulumi.Input[str]] = None,
                 codecs: Optional[pulumi.Input[str]] = None,
                 connectivity: Optional[pulumi.Input[str]] = None,
                 e911_type: Optional[pulumi.Input[str]] = None,
                 emergency_dial_strings: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 microsoft_teams_voicemail_pilot_number: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 on_prem_mcp_enabled: Optional[pulumi.Input[bool]] = None,
                 platforms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 service_locations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServicesCommunicationsGatewayServiceLocationArgs', 'ServicesCommunicationsGatewayServiceLocationArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServicesCommunicationsGatewayArgs.__new__(ServicesCommunicationsGatewayArgs)

            __props__.__dict__["api_bridge"] = api_bridge
            __props__.__dict__["auto_generated_domain_name_label_scope"] = auto_generated_domain_name_label_scope
            if codecs is None and not opts.urn:
                raise TypeError("Missing required property 'codecs'")
            __props__.__dict__["codecs"] = codecs
            if connectivity is None and not opts.urn:
                raise TypeError("Missing required property 'connectivity'")
            __props__.__dict__["connectivity"] = connectivity
            if e911_type is None and not opts.urn:
                raise TypeError("Missing required property 'e911_type'")
            __props__.__dict__["e911_type"] = e911_type
            __props__.__dict__["emergency_dial_strings"] = emergency_dial_strings
            __props__.__dict__["location"] = location
            __props__.__dict__["microsoft_teams_voicemail_pilot_number"] = microsoft_teams_voicemail_pilot_number
            __props__.__dict__["name"] = name
            __props__.__dict__["on_prem_mcp_enabled"] = on_prem_mcp_enabled
            if platforms is None and not opts.urn:
                raise TypeError("Missing required property 'platforms'")
            __props__.__dict__["platforms"] = platforms
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if service_locations is None and not opts.urn:
                raise TypeError("Missing required property 'service_locations'")
            __props__.__dict__["service_locations"] = service_locations
            __props__.__dict__["tags"] = tags
        super(ServicesCommunicationsGateway, __self__).__init__(
            'azure:voice/servicesCommunicationsGateway:ServicesCommunicationsGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_bridge: Optional[pulumi.Input[str]] = None,
            auto_generated_domain_name_label_scope: Optional[pulumi.Input[str]] = None,
            codecs: Optional[pulumi.Input[str]] = None,
            connectivity: Optional[pulumi.Input[str]] = None,
            e911_type: Optional[pulumi.Input[str]] = None,
            emergency_dial_strings: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            location: Optional[pulumi.Input[str]] = None,
            microsoft_teams_voicemail_pilot_number: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            on_prem_mcp_enabled: Optional[pulumi.Input[bool]] = None,
            platforms: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            service_locations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServicesCommunicationsGatewayServiceLocationArgs', 'ServicesCommunicationsGatewayServiceLocationArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'ServicesCommunicationsGateway':
        """
        Get an existing ServicesCommunicationsGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_bridge: Details of API bridge functionality, if required.
        :param pulumi.Input[str] auto_generated_domain_name_label_scope: Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        :param pulumi.Input[str] codecs: The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        :param pulumi.Input[str] connectivity: How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        :param pulumi.Input[str] e911_type: How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] emergency_dial_strings: A list of dial strings used for emergency calling.
        :param pulumi.Input[str] location: Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] microsoft_teams_voicemail_pilot_number: This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] on_prem_mcp_enabled: Whether an on-premises Mobile Control Point is in use.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] platforms: The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        :param pulumi.Input[str] resource_group_name: Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServicesCommunicationsGatewayServiceLocationArgs', 'ServicesCommunicationsGatewayServiceLocationArgsDict']]]] service_locations: A `service_location` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServicesCommunicationsGatewayState.__new__(_ServicesCommunicationsGatewayState)

        __props__.__dict__["api_bridge"] = api_bridge
        __props__.__dict__["auto_generated_domain_name_label_scope"] = auto_generated_domain_name_label_scope
        __props__.__dict__["codecs"] = codecs
        __props__.__dict__["connectivity"] = connectivity
        __props__.__dict__["e911_type"] = e911_type
        __props__.__dict__["emergency_dial_strings"] = emergency_dial_strings
        __props__.__dict__["location"] = location
        __props__.__dict__["microsoft_teams_voicemail_pilot_number"] = microsoft_teams_voicemail_pilot_number
        __props__.__dict__["name"] = name
        __props__.__dict__["on_prem_mcp_enabled"] = on_prem_mcp_enabled
        __props__.__dict__["platforms"] = platforms
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["service_locations"] = service_locations
        __props__.__dict__["tags"] = tags
        return ServicesCommunicationsGateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiBridge")
    def api_bridge(self) -> pulumi.Output[Optional[str]]:
        """
        Details of API bridge functionality, if required.
        """
        return pulumi.get(self, "api_bridge")

    @property
    @pulumi.getter(name="autoGeneratedDomainNameLabelScope")
    def auto_generated_domain_name_label_scope(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the scope at which the auto-generated domain name can be re-used. Possible values are `TenantReuse`, `SubscriptionReuse`, `ResourceGroupReuse` and `NoReuse` . Changing this forces a new resource to be created. Defaults to `TenantReuse`.
        """
        return pulumi.get(self, "auto_generated_domain_name_label_scope")

    @property
    @pulumi.getter
    def codecs(self) -> pulumi.Output[str]:
        """
        The voice codecs expected for communication with Teams. Possible values are `PCMA`, `PCMU`,`G722`,`G722_2`,`SILK_8` and `SILK_16`.
        """
        return pulumi.get(self, "codecs")

    @property
    @pulumi.getter
    def connectivity(self) -> pulumi.Output[str]:
        """
        How to connect back to the operator network, e.g. MAPS. Possible values is `PublicAddress`. Changing this forces a new Voice Services Communications Gateways to be created.
        """
        return pulumi.get(self, "connectivity")

    @property
    @pulumi.getter(name="e911Type")
    def e911_type(self) -> pulumi.Output[str]:
        """
        How to handle 911 calls. Possible values are `Standard` and `DirectToEsrp`.
        """
        return pulumi.get(self, "e911_type")

    @property
    @pulumi.getter(name="emergencyDialStrings")
    def emergency_dial_strings(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of dial strings used for emergency calling.
        """
        return pulumi.get(self, "emergency_dial_strings")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        Specifies the Azure Region where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="microsoftTeamsVoicemailPilotNumber")
    def microsoft_teams_voicemail_pilot_number(self) -> pulumi.Output[Optional[str]]:
        """
        This number is used in Teams Phone Mobile scenarios for access to the voicemail IVR from the native dialer.
        """
        return pulumi.get(self, "microsoft_teams_voicemail_pilot_number")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name which should be used for this Voice Services Communications Gateways. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="onPremMcpEnabled")
    def on_prem_mcp_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether an on-premises Mobile Control Point is in use.
        """
        return pulumi.get(self, "on_prem_mcp_enabled")

    @property
    @pulumi.getter
    def platforms(self) -> pulumi.Output[Sequence[str]]:
        """
        The Voice Services Communications GatewaysAvailable supports platform types. Possible values are `OperatorConnect`, `TeamsPhoneMobile`.
        """
        return pulumi.get(self, "platforms")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Resource Group where the Voice Services Communications Gateways should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="serviceLocations")
    def service_locations(self) -> pulumi.Output[Sequence['outputs.ServicesCommunicationsGatewayServiceLocation']]:
        """
        A `service_location` block as defined below.
        """
        return pulumi.get(self, "service_locations")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags which should be assigned to the Voice Services Communications Gateways.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FlexibleServerVirtualEndpointArgs', 'FlexibleServerVirtualEndpoint']

@pulumi.input_type
class FlexibleServerVirtualEndpointArgs:
    def __init__(__self__, *,
                 replica_server_id: pulumi.Input[str],
                 source_server_id: pulumi.Input[str],
                 type: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a FlexibleServerVirtualEndpoint resource.
        :param pulumi.Input[str] replica_server_id: The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        :param pulumi.Input[str] source_server_id: The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        :param pulumi.Input[str] type: The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        :param pulumi.Input[str] name: The name of the Virtual Endpoint
        """
        pulumi.set(__self__, "replica_server_id", replica_server_id)
        pulumi.set(__self__, "source_server_id", source_server_id)
        pulumi.set(__self__, "type", type)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="replicaServerId")
    def replica_server_id(self) -> pulumi.Input[str]:
        """
        The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        """
        return pulumi.get(self, "replica_server_id")

    @replica_server_id.setter
    def replica_server_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "replica_server_id", value)

    @property
    @pulumi.getter(name="sourceServerId")
    def source_server_id(self) -> pulumi.Input[str]:
        """
        The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        """
        return pulumi.get(self, "source_server_id")

    @source_server_id.setter
    def source_server_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_server_id", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Virtual Endpoint
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _FlexibleServerVirtualEndpointState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 replica_server_id: Optional[pulumi.Input[str]] = None,
                 source_server_id: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FlexibleServerVirtualEndpoint resources.
        :param pulumi.Input[str] name: The name of the Virtual Endpoint
        :param pulumi.Input[str] replica_server_id: The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        :param pulumi.Input[str] source_server_id: The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        :param pulumi.Input[str] type: The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if replica_server_id is not None:
            pulumi.set(__self__, "replica_server_id", replica_server_id)
        if source_server_id is not None:
            pulumi.set(__self__, "source_server_id", source_server_id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Virtual Endpoint
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="replicaServerId")
    def replica_server_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        """
        return pulumi.get(self, "replica_server_id")

    @replica_server_id.setter
    def replica_server_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "replica_server_id", value)

    @property
    @pulumi.getter(name="sourceServerId")
    def source_server_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        """
        return pulumi.get(self, "source_server_id")

    @source_server_id.setter
    def source_server_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_server_id", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class FlexibleServerVirtualEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 replica_server_id: Optional[pulumi.Input[str]] = None,
                 source_server_id: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Allows you to create a Virtual Endpoint associated with a Postgres Flexible Replica.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="East US")
        example_flexible_server = azure.postgresql.FlexibleServer("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            version="16",
            public_network_access_enabled=False,
            administrator_login="psqladmin",
            administrator_password="H@Sh1CoR3!",
            zone="1",
            storage_mb=32768,
            storage_tier="P30",
            sku_name="GP_Standard_D2ads_v5")
        example_replica = azure.postgresql.FlexibleServer("example_replica",
            name="example-replica",
            resource_group_name=example_flexible_server.resource_group_name,
            location=example_flexible_server.location,
            create_mode="Replica",
            source_server_id=example_flexible_server.id,
            version="16",
            public_network_access_enabled=False,
            zone="1",
            storage_mb=32768,
            storage_tier="P30",
            sku_name="GP_Standard_D2ads_v5")
        example_flexible_server_virtual_endpoint = azure.postgresql.FlexibleServerVirtualEndpoint("example",
            name="example-endpoint-1",
            source_server_id=example_flexible_server.id,
            replica_server_id=example_replica.id,
            type="ReadWrite")
        ```

        > **Note:** If creating multiple replicas, an error can occur if virtual endpoints are created before all replicas have been completed. To avoid this error, use a `depends_on` property on `postgresql.FlexibleServerVirtualEndpoint` that references all Postgres Flexible Server Replicas.

        ## Import

        A PostgreSQL Flexible Virtual Endpoint can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:postgresql/flexibleServerVirtualEndpoint:FlexibleServerVirtualEndpoint example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DBforPostgreSQL/flexibleServers/server1/virtualEndpoints/endpoint1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the Virtual Endpoint
        :param pulumi.Input[str] replica_server_id: The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        :param pulumi.Input[str] source_server_id: The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        :param pulumi.Input[str] type: The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlexibleServerVirtualEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows you to create a Virtual Endpoint associated with a Postgres Flexible Replica.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="East US")
        example_flexible_server = azure.postgresql.FlexibleServer("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            version="16",
            public_network_access_enabled=False,
            administrator_login="psqladmin",
            administrator_password="H@Sh1CoR3!",
            zone="1",
            storage_mb=32768,
            storage_tier="P30",
            sku_name="GP_Standard_D2ads_v5")
        example_replica = azure.postgresql.FlexibleServer("example_replica",
            name="example-replica",
            resource_group_name=example_flexible_server.resource_group_name,
            location=example_flexible_server.location,
            create_mode="Replica",
            source_server_id=example_flexible_server.id,
            version="16",
            public_network_access_enabled=False,
            zone="1",
            storage_mb=32768,
            storage_tier="P30",
            sku_name="GP_Standard_D2ads_v5")
        example_flexible_server_virtual_endpoint = azure.postgresql.FlexibleServerVirtualEndpoint("example",
            name="example-endpoint-1",
            source_server_id=example_flexible_server.id,
            replica_server_id=example_replica.id,
            type="ReadWrite")
        ```

        > **Note:** If creating multiple replicas, an error can occur if virtual endpoints are created before all replicas have been completed. To avoid this error, use a `depends_on` property on `postgresql.FlexibleServerVirtualEndpoint` that references all Postgres Flexible Server Replicas.

        ## Import

        A PostgreSQL Flexible Virtual Endpoint can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:postgresql/flexibleServerVirtualEndpoint:FlexibleServerVirtualEndpoint example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DBforPostgreSQL/flexibleServers/server1/virtualEndpoints/endpoint1
        ```

        :param str resource_name: The name of the resource.
        :param FlexibleServerVirtualEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlexibleServerVirtualEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 replica_server_id: Optional[pulumi.Input[str]] = None,
                 source_server_id: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlexibleServerVirtualEndpointArgs.__new__(FlexibleServerVirtualEndpointArgs)

            __props__.__dict__["name"] = name
            if replica_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'replica_server_id'")
            __props__.__dict__["replica_server_id"] = replica_server_id
            if source_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_server_id'")
            __props__.__dict__["source_server_id"] = source_server_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(FlexibleServerVirtualEndpoint, __self__).__init__(
            'azure:postgresql/flexibleServerVirtualEndpoint:FlexibleServerVirtualEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            replica_server_id: Optional[pulumi.Input[str]] = None,
            source_server_id: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'FlexibleServerVirtualEndpoint':
        """
        Get an existing FlexibleServerVirtualEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the Virtual Endpoint
        :param pulumi.Input[str] replica_server_id: The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        :param pulumi.Input[str] source_server_id: The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        :param pulumi.Input[str] type: The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlexibleServerVirtualEndpointState.__new__(_FlexibleServerVirtualEndpointState)

        __props__.__dict__["name"] = name
        __props__.__dict__["replica_server_id"] = replica_server_id
        __props__.__dict__["source_server_id"] = source_server_id
        __props__.__dict__["type"] = type
        return FlexibleServerVirtualEndpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Virtual Endpoint
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="replicaServerId")
    def replica_server_id(self) -> pulumi.Output[str]:
        """
        The Resource ID of the *Replica* Postgres Flexible Server this should be associated with
        """
        return pulumi.get(self, "replica_server_id")

    @property
    @pulumi.getter(name="sourceServerId")
    def source_server_id(self) -> pulumi.Output[str]:
        """
        The Resource ID of the *Source* Postgres Flexible Server this should be associated with.
        """
        return pulumi.get(self, "source_server_id")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of Virtual Endpoint. Currently only `ReadWrite` is supported.
        """
        return pulumi.get(self, "type")

